@@ -1,25 +1,25 @@
 """
 Current-flow betweenness centrality measures.
 """
-#    Copyright (C) 2010-2011 by 
+#    Copyright (C) 2010-2012 by
 #    Aric Hagberg <hagberg@lanl.gov>
 #    Dan Schult <dschult@colgate.edu>
 #    Pieter Swart <swart@lanl.gov>
 #    All rights reserved.
 #    BSD license.
+import random
+import networkx as nx
+from networkx.algorithms.centrality.flow_matrix import *
 __author__ = """Aric Hagberg (hagberg@lanl.gov)"""
 
 __all__ = ['current_flow_betweenness_centrality',
            'approximate_current_flow_betweenness_centrality',
            'edge_current_flow_betweenness_centrality']
 
-import random
-import networkx as nx
-from networkx.algorithms.centrality.flow_matrix import *
 
-def approximate_current_flow_betweenness_centrality(G, normalized=True, 
+def approximate_current_flow_betweenness_centrality(G, normalized=True,
                                                     weight='weight',
-                                                    dtype=float, solver='lu',
+                                                    dtype=float, solver='full',
                                                     epsilon=0.5, kmax=10000):
     r"""Compute the approximate current-flow betweenness centrality for nodes.
 
@@ -30,10 +30,10 @@ def approximate_current_flow_betweenness_centrality(G, normalized=True,
     Parameters
     ----------
     G : graph
-      A NetworkX graph 
+      A NetworkX graph
 
     normalized : bool, optional (default=True)
-      If True the betweenness values are normalized by b=b/(n-1)(n-2) where
+      If True the betweenness values are normalized by 2/[(n-1)(n-2)] where
       n is the number of nodes in G.
 
     weight : string or None, optional (default='weight')
@@ -46,12 +46,12 @@ def approximate_current_flow_betweenness_centrality(G, normalized=True,
 
     solver: string (default='lu')
        Type of linear solver to use for computing the flow matrix.
-       Options are "full" (uses most memory), "lu" (recommended), and 
+       Options are "full" (uses most memory), "lu" (recommended), and
        "cg" (uses least memory).
 
     epsilon: float
         Absolute error tolerance.
-       
+
     kmax: int
        Maximum number of sample node pairs to use for approximation.
 
@@ -59,28 +59,28 @@ def approximate_current_flow_betweenness_centrality(G, normalized=True,
     -------
     nodes : dictionary
        Dictionary of nodes with betweenness centrality as the value.
-        
+
     See Also
     --------
     current_flow_betweenness_centrality
 
     Notes
     -----
-    The running time is `O((1/\epsilon^2)m{\sqrt k} \log n)` 
+    The running time is `O((1/\epsilon^2)m{\sqrt k} \log n)`
     and the space required is `O(m)` for n nodes and m edges.
 
-    If the edges have a 'weight' attribute they will be used as 
+    If the edges have a 'weight' attribute they will be used as
     weights in this algorithm.  Unspecified weights are set to 1.
 
     References
     ----------
-    .. [1] Centrality Measures Based on Current Flow. 
-       Ulrik Brandes and Daniel Fleischer,
-       Proc. 22nd Symp. Theoretical Aspects of Computer Science (STACS '05). 
-       LNCS 3404, pp. 533-544. Springer-Verlag, 2005. 
+    .. [1] Ulrik Brandes and Daniel Fleischer:
+       Centrality Measures Based on Current Flow.
+       Proc. 22nd Symp. Theoretical Aspects of Computer Science (STACS '05).
+       LNCS 3404, pp. 533-544. Springer-Verlag, 2005.
        http://www.inf.uni-konstanz.de/algo/publications/bf-cmbcf-05.pdf
     """
-    from networkx.utils import reverse_cuthill_mckee_ordering 
+    from networkx.utils import reverse_cuthill_mckee_ordering
     try:
         import numpy as np
     except ImportError:
@@ -105,10 +105,10 @@ def approximate_current_flow_betweenness_centrality(G, normalized=True,
     # make a copy with integer labels according to rcm ordering
     # this could be done without a copy if we really wanted to
     H = nx.relabel_nodes(G,dict(zip(ordering,range(n))))
-    L = laplacian_sparse_matrix(H, nodelist=range(n), weight=weight, 
+    L = laplacian_sparse_matrix(H, nodelist=range(n), weight=weight,
                                 dtype=dtype, format='csc')
     C = solvername[solver](L, dtype=dtype) # initialize solver
-    betweenness = dict.fromkeys(H,0.0) 
+    betweenness = dict.fromkeys(H,0.0)
     nb = (n-1.0)*(n-2.0) # normalization factor
     cstar = n*(n-1)/nb
     l = 1 # parameter in approximation, adjustable
@@ -138,7 +138,7 @@ def approximate_current_flow_betweenness_centrality(G, normalized=True,
 
 
 def current_flow_betweenness_centrality(G, normalized=True, weight='weight',
-                                        dtype=float, solver='lu'):
+                                        dtype=float, solver='full'):
     r"""Compute current-flow betweenness centrality for nodes.
 
     Current-flow betweenness centrality uses an electrical current
@@ -151,10 +151,10 @@ def current_flow_betweenness_centrality(G, normalized=True, weight='weight',
     Parameters
     ----------
     G : graph
-      A NetworkX graph 
+      A NetworkX graph
 
     normalized : bool, optional (default=True)
-      If True the betweenness values are normalized by b=b/(n-1)(n-2) where
+      If True the betweenness values are normalized by 2/[(n-1)(n-2)] where
       n is the number of nodes in G.
 
     weight : string or None, optional (default='weight')
@@ -167,14 +167,14 @@ def current_flow_betweenness_centrality(G, normalized=True, weight='weight',
 
     solver: string (default='lu')
        Type of linear solver to use for computing the flow matrix.
-       Options are "full" (uses most memory), "lu" (recommended), and 
+       Options are "full" (uses most memory), "lu" (recommended), and
        "cg" (uses least memory).
 
     Returns
     -------
     nodes : dictionary
        Dictionary of nodes with betweenness centrality as the value.
-        
+
     See Also
     --------
     approximate_current_flow_betweenness_centrality
@@ -185,36 +185,36 @@ def current_flow_betweenness_centrality(G, normalized=True, weight='weight',
     Notes
     -----
     Current-flow betweenness can be computed in `O(I(n-1)+mn \log n)`
-    time [1]_, where `I(n-1)` is the time needed to compute the 
+    time [1]_, where `I(n-1)` is the time needed to compute the
     inverse Laplacian.  For a full matrix this is `O(n^3)` but using
     sparse methods you can achieve `O(nm{\sqrt k})` where `k` is the
-    Laplacian matrix condition number.  
+    Laplacian matrix condition number.
 
-    The space required is `O(nw) where `w` is the width of the sparse
+    The space required is `O(nw)` where `w` is the width of the sparse
     Laplacian matrix.  Worse case is `w=n` for `O(n^2)`.
 
-    If the edges have a 'weight' attribute they will be used as 
+    If the edges have a 'weight' attribute they will be used as
     weights in this algorithm.  Unspecified weights are set to 1.
 
     References
     ----------
-    .. [1] Centrality Measures Based on Current Flow. 
+    .. [1] Centrality Measures Based on Current Flow.
        Ulrik Brandes and Daniel Fleischer,
-       Proc. 22nd Symp. Theoretical Aspects of Computer Science (STACS '05). 
-       LNCS 3404, pp. 533-544. Springer-Verlag, 2005. 
+       Proc. 22nd Symp. Theoretical Aspects of Computer Science (STACS '05).
+       LNCS 3404, pp. 533-544. Springer-Verlag, 2005.
        http://www.inf.uni-konstanz.de/algo/publications/bf-cmbcf-05.pdf
 
     .. [2] A measure of betweenness centrality based on random walks,
        M. E. J. Newman, Social Networks 27, 39-54 (2005).
     """
-    from networkx.utils import reverse_cuthill_mckee_ordering 
+    from networkx.utils import reverse_cuthill_mckee_ordering
     try:
         import numpy as np
     except ImportError:
         raise ImportError('current_flow_betweenness_centrality requires NumPy ',
                           'http://scipy.org/')
     try:
-        import scipy 
+        import scipy
     except ImportError:
         raise ImportError('current_flow_betweenness_centrality requires SciPy ',
                           'http://scipy.org/')
@@ -229,7 +229,7 @@ def current_flow_betweenness_centrality(G, normalized=True, weight='weight',
     # this could be done without a copy if we really wanted to
     H = nx.relabel_nodes(G,dict(zip(ordering,range(n))))
     betweenness = dict.fromkeys(H,0.0) # b[v]=0 for v in H
-    for row,(s,t) in flow_matrix_row(H, weight=weight, dtype=dtype, 
+    for row,(s,t) in flow_matrix_row(H, weight=weight, dtype=dtype,
                                      solver=solver):
         pos = dict(zip(row.argsort()[::-1],range(n)))
         for i in range(n):
@@ -244,9 +244,9 @@ def current_flow_betweenness_centrality(G, normalized=True, weight='weight',
     return dict((ordering[k],v) for k,v in betweenness.items())
 
 
-def edge_current_flow_betweenness_centrality(G, normalized=True, 
+def edge_current_flow_betweenness_centrality(G, normalized=True,
                                              weight='weight',
-                                             dtype=float, solver='lu'):
+                                             dtype=float, solver='full'):
     """Compute current-flow betweenness centrality for edges.
 
     Current-flow betweenness centrality uses an electrical current
@@ -259,10 +259,10 @@ def edge_current_flow_betweenness_centrality(G, normalized=True,
     Parameters
     ----------
     G : graph
-      A NetworkX graph 
+      A NetworkX graph
 
     normalized : bool, optional (default=True)
-      If True the betweenness values are normalized by b=b/(n-1)(n-2) where
+      If True the betweenness values are normalized by 2/[(n-1)(n-2)] where
       n is the number of nodes in G.
 
     weight : string or None, optional (default='weight')
@@ -275,14 +275,14 @@ def edge_current_flow_betweenness_centrality(G, normalized=True,
 
     solver: string (default='lu')
        Type of linear solver to use for computing the flow matrix.
-       Options are "full" (uses most memory), "lu" (recommended), and 
+       Options are "full" (uses most memory), "lu" (recommended), and
        "cg" (uses least memory).
 
     Returns
     -------
     nodes : dictionary
        Dictionary of edge tuples with betweenness centrality as the value.
-        
+
     See Also
     --------
     betweenness_centrality
@@ -292,36 +292,36 @@ def edge_current_flow_betweenness_centrality(G, normalized=True,
     Notes
     -----
     Current-flow betweenness can be computed in `O(I(n-1)+mn \log n)`
-    time [1]_, where `I(n-1)` is the time needed to compute the 
+    time [1]_, where `I(n-1)` is the time needed to compute the
     inverse Laplacian.  For a full matrix this is `O(n^3)` but using
     sparse methods you can achieve `O(nm{\sqrt k})` where `k` is the
-    Laplacian matrix condition number.  
+    Laplacian matrix condition number.
 
     The space required is `O(nw) where `w` is the width of the sparse
     Laplacian matrix.  Worse case is `w=n` for `O(n^2)`.
 
-    If the edges have a 'weight' attribute they will be used as 
+    If the edges have a 'weight' attribute they will be used as
     weights in this algorithm.  Unspecified weights are set to 1.
 
     References
     ----------
-    .. [1] Centrality Measures Based on Current Flow. 
+    .. [1] Centrality Measures Based on Current Flow.
        Ulrik Brandes and Daniel Fleischer,
-       Proc. 22nd Symp. Theoretical Aspects of Computer Science (STACS '05). 
-       LNCS 3404, pp. 533-544. Springer-Verlag, 2005. 
+       Proc. 22nd Symp. Theoretical Aspects of Computer Science (STACS '05).
+       LNCS 3404, pp. 533-544. Springer-Verlag, 2005.
        http://www.inf.uni-konstanz.de/algo/publications/bf-cmbcf-05.pdf
 
-    .. [2] A measure of betweenness centrality based on random walks, 
+    .. [2] A measure of betweenness centrality based on random walks,
        M. E. J. Newman, Social Networks 27, 39-54 (2005).
     """
-    from networkx.utils import reverse_cuthill_mckee_ordering 
+    from networkx.utils import reverse_cuthill_mckee_ordering
     try:
         import numpy as np
     except ImportError:
         raise ImportError('current_flow_betweenness_centrality requires NumPy ',
                           'http://scipy.org/')
     try:
-        import scipy 
+        import scipy
     except ImportError:
         raise ImportError('current_flow_betweenness_centrality requires SciPy ',
                           'http://scipy.org/')
@@ -340,7 +340,7 @@ def edge_current_flow_betweenness_centrality(G, normalized=True,
         nb=(n-1.0)*(n-2.0) # normalization factor
     else:
         nb=2.0
-    for row,(e) in flow_matrix_row(H, weight=weight, dtype=dtype, 
+    for row,(e) in flow_matrix_row(H, weight=weight, dtype=dtype,
                                    solver=solver):
         pos=dict(zip(row.argsort()[::-1],range(1,n+1)))
         for i in range(n):
@@ -359,5 +359,3 @@ def setup_module(module):
         import scipy
     except:
         raise SkipTest("NumPy not available")
-
-
